@@ -305,6 +305,7 @@ class Config
         std::string sVersionNumber;
         std::string sEmail;
         std::string sPassword;
+        std::string sGalaxyBuildSortingOrder;
 
         // Lists
         Blacklist blacklist;
@@ -324,6 +325,7 @@ class Config
         int iProgressInterval;
         int iMsgLevel;
         unsigned int iListFormat;
+        unsigned int iUnitFormat;
 
         Json::Value transformationsJSON;
 };
