@@ -144,6 +144,12 @@ int main(int argc, char *argv[])
         "- %dlc_title%\n"
         "- %dlc_title_stripped%";
 
+    // Help text for subdir options
+    std::string galaxy_sort_help_text = "\nOptions:\n"
+        "\"none\" - no sorting\n"
+        "\"date\" - sort by date\n"
+        "\"score\" - sort by date and deprioritize branches, deprioritizes compatibility branches even more\n";
+
     // Help text for include and exclude options
     std::string include_options_text;
     for (unsigned int i = 0; i < GlobalConstants::INCLUDE_OPTIONS.size(); ++i)
@@ -205,6 +211,7 @@ int main(int argc, char *argv[])
         std::string sGalaxyArch;
         std::string sGalaxyCDN;
         std::string sListFormat;
+        std::string sUnitFormat;
         Globals::globalConfig.bReport = false;
         // Commandline options (no config file)
         options_cli_no_cfg.add_options()
@@ -298,11 +305,13 @@ int main(int argc, char *argv[])
             ("no-fast-status-check", bpo::value<bool>(&bNoFastStatusCheck)->zero_tokens()->default_value(false), "Don't use fast status check.\nMakes --status much slower but able to catch corrupted files by calculating local file hash for all files.")
             ("trust-api-for-extras", bpo::value<bool>(&Globals::globalConfig.bTrustAPIForExtras)->zero_tokens()->default_value(false), "Trust API responses for extras to be correct.")
             ("interface", bpo::value<std::string>(&Globals::globalConfig.curlConf.sInterface)->default_value(""), "Perform operations using a specified network interface")
+            ("unit-format", bpo::value<std::string>(&sUnitFormat)->default_value("IEC"), "Select unit format to use: IEC or SI")
         ;
 
         options_cli_no_cfg_hidden.add_options()
             ("login-email", bpo::value<std::string>(&Globals::globalConfig.sEmail)->default_value(""), "login email")
             ("login-password", bpo::value<std::string>(&Globals::globalConfig.sPassword)->default_value(""), "login password")
+            ("galaxy-builds-sort", bpo::value<std::string>(&Globals::globalConfig.sGalaxyBuildSortingOrder)->default_value("score"), ("Sorting order for Galaxy builds" + galaxy_sort_help_text).c_str())
         ;
 
         options_cli_experimental.add_options()
@@ -579,6 +588,15 @@ int main(int argc, char *argv[])
         Globals::globalConfig.dlConf.iInclude = include_value & ~exclude_value;
 
         Globals::globalConfig.iListFormat = Util::getOptionValue(sListFormat, GlobalConstants::LIST_FORMAT, false);
+
+        if (sUnitFormat == "SI" || sUnitFormat == "si")
+        {
+            Globals::globalConfig.iUnitFormat = GlobalConstants::UNIT_FORMAT_SI;
+        }
+        else
+        {
+            Globals::globalConfig.iUnitFormat = GlobalConstants::UNIT_FORMAT_IEC;
+        }
     }
     catch (std::exception& e)
     {
